@@ -28,7 +28,7 @@ exchange = None
 container_files_path = None
 
 container_version = "4"
-pypi_version = "0.0.28"
+pypi_version = "0.0.29"
 
 
 def deal_with_stdout():
@@ -738,7 +738,7 @@ async def heartbeat_loop(debug: bool):
 
 
 # start our service
-def start_service_and_heartbeat(debug=False):
+def start_service_and_heartbeat(debug: bool = False):
     loop = asyncio.get_event_loop()
     get_version_info()
     asyncio.gather(mythic_service(debug), heartbeat_loop(debug))
